@@ -45,9 +45,6 @@ def parse_args(argv, no_yaml=False):
          monasca-notification is an engine responsible for
          transforming alarm transitions into proper notifications
          ''')
-
-    conf.register_enabled_plugin_opts(CONF)
-
     log.setup(CONF,
               product_name='monasca-notification',
               version=version.version_string)
@@ -63,5 +60,6 @@ def parse_args(argv, no_yaml=False):
 def set_from_yaml():
     if CONF.yaml_config:
         LOG.info('Detected usage of deprecated YAML configuration')
-        yaml_cfg = yaml.safe_load(open(CONF.yaml_config, 'rb'))
+        with open(CONF.yaml_config, 'rb') as ycf:
+            yaml_cfg = yaml.safe_load(ycf.read())
         conf.load_from_yaml(yaml_cfg)
